@@ -153,3 +153,22 @@ class LimeTabular(TabularExplainer):
                     importance_scores=[v[1] for v in values],
                 )
         return explanations
+
+    def save(
+            self,
+            directory: str,
+            filename: str = None,
+            **kwargs
+    ):
+        """
+        Saves the initialized explainer.
+
+        :param directory: The folder for the dumped explainer.
+        :param filename: The filename (the explainer class name if it is None).
+        """
+        super().save(
+            directory=directory,
+            filename=filename,
+            ignored_attributes=["data"],
+            **kwargs
+        )
