@@ -24,13 +24,22 @@ class TestTimeseries(unittest.TestCase):
     def test(self):
         ts = Timeseries.from_pd(self.df)
         self.assertEqual(ts.ts_len, 2)
-        self.assertEqual(ts.shape, (1, 2, 4))
-        self.assertEqual(len(ts), 1)
+        self.assertEqual(ts.shape, (2, 4))
+        self.assertEqual(len(ts), 2)
         df = ts.to_pd()
         self.assertEqual(df.index.year.values[0], 2017)
         self.assertEqual(df.index.month.values[0], 12)
         x = ts.to_numpy()
-        self.assertEqual(x[0][1][1], 506.424)
+        self.assertEqual(x[1][1], 506.424)
+        x = ts[[1, 0]]
+        self.assertEqual(x.values[1][1], 394.507)
+
+        timestamp_info = Timeseries.get_timestamp_info(ts)
+        ts_a = Timeseries.reset_timestamp_index(ts, timestamp_info)
+        ts_b = Timeseries.restore_timestamp_index(ts_a, timestamp_info)
+        self.assertListEqual(list(ts.columns), list(ts_b.columns))
+        self.assertListEqual(list(ts.index), list(ts_b.index))
+        self.assertEqual(ts.to_pd().equals(ts_b.to_pd()), True)
 
 
 if __name__ == "__main__":
